Function glifparser::read_from_filename
source · pub fn read_from_filename<F: AsRef<Path> + Clone, PD: PointData>(
filename: F
) -> Result<Glif<PD>, GlifParserError>Expand description
If you have a known filename, it is always preferable to call this function, as it sets the
filename on the Glif