Struct glifparser::glif::xml::Element

source ·
pub struct Element {
    pub prefix: Option<String>,
    pub namespace: Option<String>,
    pub namespaces: Option<Namespace>,
    pub name: String,
    pub attributes: IndexMap<String, String, RandomState>,
    pub children: Vec<XMLNode, Global>,
}
Represents an XML element.

Fields

prefix: Option<String>

This elements prefix, if any

namespace: Option<String>

This elements namespace, if any

namespaces: Option<Namespace>

The full list of namespaces, if any

The Namespace type is exported from the xml-rs crate.

name: String

The name of the Element. Does not include any namespace info

attributes: IndexMap<String, String, RandomState>

The Element attributes

By default, this is a HashMap, but if the optional “attribute-order” feature is enabled, this is an IndexMap, which will retain item insertion order.

children: Vec<XMLNode, Global>

Children

Implementations

Create a new empty element with given name

All other fields are empty

Parses some data into a list of XMLNodes

This is useful when you want to capture comments or processing instructions that appear before or after the root node

Parses some data into an Element

Writes out this element as the root element in an new XML document

Writes out this element as the root element in a new XML document using the provided configuration

Find a child element with the given name and return a reference to it.

Both &str and String implement ElementPredicate and can be used to search for child elements that match the given element name with .get_child("element_name"). You can also search by ("element_name", "tag_name") tuple.

Note: this will only return Elements. To get other nodes (like comments), iterate through the children field.

Find a child element with the given name and return a mutable reference to it.

Find a child element with the given name, remove and return it.

Returns the inner text/cdata of this element, if any.

If there are multiple text/cdata nodes, they will be all concatenated into one string.