Module glifparser::outline
source · Expand description
.glif <outline> and <contour>
Re-exports
pub use contour::Reverse;
Modules
Structs
Enums
- Representation of glyph data as pen operations, rather than as
Point’s.
Traits
kurbo::BezPathto type (most useful forOutline)- Type (most useful on
Outline) tokurbo::BezPath - Only knocks out exactly equal floats. For colocated within see
MFEKmath::Fixup::assert_colocated_within. - This trait is primarily intended for easing
.glifequality testing internally by our test suite. It therefore doesn’t do any of the fancy things it could like change point types and assert handles as colocated. ConsiderMFEKmath::Fixup,RefigurePointTypes, etc., not this. (…Or perhaps together?) - Split a long vec of pen operations into constitutent contours.
Type Definitions
- A list of pen operations that should contain one and only one contour.
- A list of lists of pen operations creating an outline of
Vec::len()contours.