.glif <point>
Structs
- Glif
Point - A “close to the source” .glif
<point> - Kurbo
Point - A 2D point.
- Point
- A Skia-friendly point
Enums
- Handle
- A handle on a point
- Point
Type - Which
Handle - For use by
Point::handle_or_colocatedTODO: Replace with Option
Traits
- From
Kurbo Point - IsValid
- Point
Data - API consumers may put any clonable type as an associated type to Glif, which will appear along with each Point. You could use this to implement, e.g., hyperbeziers. The Glif Point’s would still represent a Bézier curve, but you could put hyperbezier info along with the Point.
- Point
Like - ToKurbo
Point